# apgmx

**⚠️ This project was created for internal use within [Akari](https://github.com/No767/Akari), support will be minimal.**

A database migrations tool for asyncpg (fork of RDanny's migrations system)

## Key Features

- Simple migrations 
- Loads database uri either from .json config or from exported environment variables

## Installing

Currently as of now, PyPi releases are not available, so this project can only be installed via git: 

```bash
pip install git+https://github.com/No767/apgmx
```

## Usage

See `apgmx --help` for more info and usage

## Credits

Thanks to Danny and the contributors of RoboDanny for providing the base of this project.